@@ -229,14 +229,14 @@ class MSM(_Model):
 
     @property
     def dt_model(self):
+        """Description of the physical time corresponding to the lag."""
         return self._dt_model
 
     @dt_model.setter
     def dt_model(self, value):
         self._dt_model = value
-
-        # this is only used internally?
         from pyemma.util.units import TimeUnit
+        # this is used internally to scale output times to a physical time unit.
         self._timeunit_model = TimeUnit(self.dt_model)
 
 
@@ -247,28 +247,15 @@ class MSM(_Model):
     @property
     @alias('stationary_distribution')
     def pi(self):
+        """The stationary distribution on the MSM states"""
         return self._pi
 
     @pi.setter
     def pi(self, value):
-        """The stationary distribution on the MSM states"""
         if value is None and self.P is not None:
             from msmtools.analysis import stationary_distribution as _statdist
             value = _statdist(self.P)
-        elif self.P is not None:
-            # check input
-            # this only holds for a unique measure...
-            try:
-                test_unique = self.P.dot(value)
-                _np.testing.assert_allclose(test_unique, value,
-                                            atol=1e-14, rtol=0.01, err_msg='given stationary distribution '
-                                                                           'is not a valid unique measure.')
-
-            except AssertionError:
-                pass
-                # import logging
-                # logger = logging.getLogger('pyemma.msm')
-                # logger.exception("pi not valid/unique")
+        elif value is not None:
             # check sum is one
             _np.testing.assert_allclose(_np.sum(value), 1, atol=1e-14)
         self._pi = value
