@@ -33,7 +33,8 @@ import pkg_resources
 
 # for IDE stupidity, just add a new cfg var here, if you add a property to Wrapper
 cfg_dir = default_config_file = default_logging_config = logging_config = \
-    show_progress_bars = used_filenames = use_trajectory_lengths_cache = None
+    show_progress_bars = used_filenames = use_trajectory_lengths_cache = \
+    check_version = None
 
 __all__ = (
            'cfg_dir',
@@ -46,6 +47,7 @@ __all__ = (
            'traj_info_max_entries',
            'traj_info_max_size',
            'coordinates_check_output',
+           'check_version',
            )
 
 if six.PY2:
@@ -373,6 +375,14 @@ In order to load a pre-saved configuration file, use the :py:func:`load` method:
     def coordinates_check_output(self, val):
         self._conf_values.set('pyemma', 'coordinates_check_output', str(val))
 
+    @property
+    def check_version(self):
+        return self._conf_values.getboolean('pyemma', 'check_version')
+
+    @check_version.setter
+    def check_version(self, val):
+        self._conf_values.set('pyemma', 'check_version', str(val))
+
     ### FIlE HANDLING
 
     def __copy_default_files_to_cfg_dir(self, target_dir):
